@@ -26,95 +26,12 @@ no warnings qw(recursion qw);
 use strict;
 
 use vars qw($VERSION $STRING_VERSION);
-$VERSION        = '2.064000';
+$VERSION        = '2.066000';
 $STRING_VERSION = $VERSION;
 ## no critic(BuiltinFunctions::ProhibitStringyEval)
 $VERSION = eval $VERSION;
 ## use critic
 
-BEGIN {
-    my $structure = <<'END_OF_STRUCTURE';
-
-    :package=Marpa::R2::Internal::Symbol
-    ID { Unique ID }
-    BLESSING
-    LEXEME_SEMANTICS
-
-END_OF_STRUCTURE
-    Marpa::R2::offset($structure);
-} ## end BEGIN
-
-BEGIN {
-    my $structure = <<'END_OF_STRUCTURE';
-
-    :package=Marpa::R2::Internal::Rule
-
-    ID
-    NAME
-    DISCARD_SEPARATION
-    MASK { Semantic mask of RHS symbols }
-    ACTION_NAME
-    BLESSING
-
-END_OF_STRUCTURE
-    Marpa::R2::offset($structure);
-} ## end BEGIN
-
-BEGIN {
-    my $structure = <<'END_OF_STRUCTURE';
-
-    :package=Marpa::R2::Internal::Grammar
-
-    C { A C structure }
-    TRACER { Also contains a copy of the C structure.
-       It is used frequently, so that an easy memoization
-       is probably worthwhile to save a the extra
-       indirection.
-    }
-    RULES { array of rule refs }
-    SYMBOLS { array of symbol refs }
-    ACTIONS { Default package in which to find actions }
-    BLESS_PACKAGE { Default package into which nodes are blessed }
-    DEFAULT_ACTION { Action for rules without one }
-    TRACE_FILE_HANDLE
-    WARNINGS { print warnings about grammar? }
-    RULE_NAME_REQUIRED
-    RULE_BY_NAME
-    INTERFACE { currently 'standard' or 'stuifzand' }
-    INTERNAL { internal grammar -- relax various restrictions }
-
-    CHARACTER_CLASSES { an hash of
-    character class regex by symbol name.
-    Used before precomputation. }
-
-    CHARACTER_CLASS_TABLE { An array of symbol ID and
-    regex.  Used after precomputation. }
-
-    =LAST_BASIC_DATA_FIELD
-
-    { === Evaluator Fields === }
-
-    DEFAULT_EMPTY_ACTION { default value for empty rules }
-    ACTION_OBJECT
-    INFINITE_ACTION
-
-    =LAST_EVALUATOR_FIELD
-
-    PROBLEMS { fatal problems }
-
-    =LAST_RECOGNIZER_FIELD
-
-    START_NAME { name of original symbol }
-    INACCESSIBLE_OK
-    UNPRODUCTIVE_OK
-    TRACE_RULES
-
-    =LAST_FIELD
-
-END_OF_STRUCTURE
-    Marpa::R2::offset($structure);
-} ## end BEGIN
-
 package Marpa::R2::Internal::Grammar;
 
 use English qw( -no_match_vars );
