@@ -20,7 +20,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION $STRING_VERSION);
-$VERSION        = '2.064000';
+$VERSION        = '2.066000';
 $STRING_VERSION = $VERSION;
 ## no critic(BuiltinFunctions::ProhibitStringyEval)
 $VERSION = eval $VERSION;
@@ -33,33 +33,37 @@ use English qw( -no_match_vars );
 sub new {
     my ( $class, $p_rules_source, $parse ) = @_;
 
-    my $meta_recce = Marpa::R2::Internal::Scanless::meta_recce();
+    my $meta_recce   = Marpa::R2::Internal::Scanless::meta_recce();
     my $meta_grammar = $meta_recce->[Marpa::R2::Inner::Scanless::R::GRAMMAR];
     state $mask_by_rule_id =
         $meta_grammar->[Marpa::R2::Inner::Scanless::G::MASK_BY_RULE_ID];
     $meta_recce->read($p_rules_source);
 
-    my $thick_meta_g1_grammar = $meta_grammar->[Marpa::R2::Inner::Scanless::G::THICK_G1_GRAMMAR];
+    my $thick_meta_g1_grammar =
+        $meta_grammar->[Marpa::R2::Inner::Scanless::G::THICK_G1_GRAMMAR];
     my $meta_g1_tracer       = $thick_meta_g1_grammar->tracer();
     my $thin_meta_g1_grammar = $thick_meta_g1_grammar->thin();
-    my $thick_meta_g1_recce = $meta_recce->[Marpa::R2::Inner::Scanless::R::THICK_G1_RECCE];
-    my $thick_g1_recce = $meta_recce->[Marpa::R2::Inner::Scanless::R::THICK_G1_RECCE];
+    my $thick_meta_g1_recce =
+        $meta_recce->[Marpa::R2::Inner::Scanless::R::THICK_G1_RECCE];
+    my $thick_g1_recce =
+        $meta_recce->[Marpa::R2::Inner::Scanless::R::THICK_G1_RECCE];
 
     my $value_ref = $meta_recce->value();
-    Marpa::R2::exception("Parse of BNF/Scanless source failed") if not defined $value_ref;
+    Marpa::R2::exception('Parse of BNF/Scanless source failed')
+        if not defined $value_ref;
     $parse->{meta_recce} = $meta_recce if defined $parse;
     return bless ${$value_ref}, $class;
 
-}
+} ## end sub new
 
 sub Marpa::R2::Internal::MetaAST::Parse::substring {
-    my ($parse, $start, $length) = @_;
-    my $meta_slr = $parse->{meta_recce};
+    my ( $parse, $start, $length ) = @_;
+    my $meta_slr      = $parse->{meta_recce};
     my $thin_meta_slr = $meta_slr->[Marpa::R2::Inner::Scanless::R::C];
-    my $string = $thin_meta_slr->substring($start, $length);
+    my $string        = $thin_meta_slr->substring( $start, $length );
     chomp $string;
     return $string;
-}
+} ## end sub Marpa::R2::Internal::MetaAST::Parse::substring
 
 sub ast_to_hash {
     my ( $ast, $parse ) = @_;
@@ -67,7 +71,7 @@ sub ast_to_hash {
     $parse->{g1_rules} = [];
     bless $parse, 'Marpa::R2::Internal::MetaAST::Parse';
 
-    my (undef, undef, @statements) = @{$ast};
+    my ( undef, undef, @statements ) = @{$ast};
 
     # This is the last ditch exception catcher
     # It forces all Marpa exceptions to be die's,
@@ -94,7 +98,6 @@ sub ast_to_hash {
         $lex_rhs{$_} = 1 for @{ $lex_rule->{rhs} };
     }
 
-    my $lexeme_default_adverbs = $parse->{lexeme_default_adverbs};
     my $g1_symbols             = {};
     my %is_lexeme =
         map { ( $_, 1 ); } grep { not $lex_rhs{$_} } keys %lex_lhs;
@@ -113,17 +116,17 @@ sub ast_to_hash {
                             qq{   Problematic lexeme was <$lexeme>\n}
                         );
                     } ## end if ( $lexeme =~ / [^ [:alnum:]] /xms )
-                    my $blessing = $lexeme;
-                    $blessing =~ s/[ ]/_/gxms;
-                    $g1_symbols->{$lexeme}->{bless} = $blessing;
+                    my $blessing_by_name = $lexeme;
+                    $blessing_by_name =~ s/[ ]/_/gxms;
+                    $g1_symbols->{$lexeme}->{bless} = $blessing_by_name;
                     last DETERMINE_BLESSING;
                 } ## end if ( $blessing eq '::name' )
-                if ( $blessing =~ / [^\w] /xms ) {
+                if ( $blessing =~ / [\W] /xms ) {
                     Marpa::R2::exception(
                         qq{Blessing lexeme as '$blessing' is not allowed\n},
                         qq{   Problematic lexeme was <$lexeme>\n}
                     );
-                } ## end if ( $blessing =~ / [^\w] /xms )
+                } ## end if ( $blessing =~ / [\W] /xms )
                 $g1_symbols->{$lexeme}->{bless} = $blessing;
             } ## end DETERMINE_BLESSING:
             $g1_symbols->{$lexeme}->{semantics} = $action;
@@ -163,10 +166,11 @@ sub Marpa::R2::Internal::MetaAST::Proto_Alternative::combine {
     for my $hash_to_add (@hashes) {
         for my $key ( keys %{$hash_to_add} ) {
             ## expect to be caught and rethrown
-            die qq{A Marpa rule contained a duplicate key\n}, qq{  The key was "$key"\n}
-            if exists $self->{$key};
+            die qq{A Marpa rule contained a duplicate key\n},
+                qq{  The key was "$key"\n}
+                if exists $self->{$key};
             $self->{$key} = $hash_to_add->{$key};
-        }
+        } ## end for my $key ( keys %{$hash_to_add} )
     } ## end for my $hash_to_add (@hashes)
     return $self;
 } ## end sub Marpa::R2::Internal::MetaAST::Proto_Alternative::combine
@@ -179,6 +183,7 @@ sub Marpa::R2::Internal::MetaAST::Parse::bless_hash_rule {
     FIND_BLESSING: {
         last FIND_BLESSING if $blessing =~ /\A [\w] /xms;
         return if $blessing eq '::undef';
+
         # Rule may be half-formed, but assume we have lhs
         my $lhs = $hash_rule->{lhs};
         if ( $blessing eq '::lhs' ) {
@@ -192,15 +197,14 @@ sub Marpa::R2::Internal::MetaAST::Parse::bless_hash_rule {
             $blessing =~ s/[ ]/_/gxms;
             last FIND_BLESSING;
         } ## end if ( $blessing eq '::lhs' )
-        Marpa::R2::exception(
-            qq{Unknown blessing "$blessing"\n}
-        );
+        Marpa::R2::exception( qq{Unknown blessing "$blessing"\n} );
     } ## end FIND_BLESSING:
     $hash_rule->{bless} = $blessing;
     return 1;
-} ## end sub bless_hash_rule
+} ## end sub Marpa::R2::Internal::MetaAST::Parse::bless_hash_rule
 
 sub Marpa::R2::Internal::MetaAST_Nodes::bare_name::name { return $_[0]->[2] }
+
 sub Marpa::R2::Internal::MetaAST_Nodes::reserved_action_name::name {
     my ( $self, $parse ) = @_;
     return $self->[2];
@@ -225,7 +229,7 @@ sub Marpa::R2::Internal::MetaAST_Nodes::reserved_blessing_name::name {
 }
 
 sub Marpa::R2::Internal::MetaAST_Nodes::blessing_name::name {
-    my ($self, $parse) = @_;
+    my ( $self, $parse ) = @_;
     return $self->[2]->name($parse);
 }
 
@@ -234,14 +238,14 @@ sub Marpa::R2::Internal::MetaAST_Nodes::standard_name::name {
 }
 
 sub Marpa::R2::Internal::MetaAST_Nodes::lhs::name {
-    my ($values, $parse) = @_;
-    my (undef, undef, $symbol) = @{$values};
+    my ( $values, $parse ) = @_;
+    my ( undef, undef, $symbol ) = @{$values};
     return $symbol->name($parse);
 }
 
 # After development, delete this
 sub Marpa::R2::Internal::MetaAST_Nodes::lhs::evaluate {
-    my ($values, $parse) = @_;
+    my ( $values, $parse ) = @_;
     return $values->name($parse);
 }
 
@@ -267,34 +271,36 @@ sub Marpa::R2::Internal::MetaAST_Nodes::op_declare_bnf::op {
 
 sub Marpa::R2::Internal::MetaAST_Nodes::bracketed_name::name {
     my ($values) = @_;
-    my (undef, undef, $bracketed_name) = @{$values};
+    my ( undef, undef, $bracketed_name ) = @{$values};
 
     # normalize whitespace
     $bracketed_name =~ s/\A [<] \s*//xms;
     $bracketed_name =~ s/ \s* [>] \z//xms;
     $bracketed_name =~ s/ \s+ / /gxms;
     return $bracketed_name;
-} ## end sub evaluate
+} ## end sub Marpa::R2::Internal::MetaAST_Nodes::bracketed_name::name
 
 sub Marpa::R2::Internal::MetaAST_Nodes::single_quoted_name::name {
     my ($values) = @_;
-    my (undef, undef, $single_quoted_name) = @{$values};
+    my ( undef, undef, $single_quoted_name ) = @{$values};
 
     # normalize whitespace
     $single_quoted_name =~ s/\A ['] \s*//xms;
     $single_quoted_name =~ s/ \s* ['] \z//xms;
     $single_quoted_name =~ s/ \s+ / /gxms;
     return $single_quoted_name;
-} ## end sub evaluate
+} ## end sub Marpa::R2::Internal::MetaAST_Nodes::single_quoted_name::name
 
-sub Marpa::R2::Internal::MetaAST_Nodes::parenthesized_rhs_primary_list::evaluate {
+sub Marpa::R2::Internal::MetaAST_Nodes::parenthesized_rhs_primary_list::evaluate
+{
     my ( $data, $parse ) = @_;
-    my (undef, undef, @values) = @{$data};
+    my ( undef, undef, @values ) = @{$data};
     my @symbol_lists = map { $_->evaluate($parse); } @values;
-    my $flattened_list = Marpa::R2::Internal::MetaAST::Symbol_List->combine(@symbol_lists);
+    my $flattened_list =
+        Marpa::R2::Internal::MetaAST::Symbol_List->combine(@symbol_lists);
     $flattened_list->mask_set(0);
     return $flattened_list;
-}
+} ## end sub Marpa::R2::Internal::MetaAST_Nodes::parenthesized_rhs_primary_list::evaluate
 
 sub Marpa::R2::Internal::MetaAST_Nodes::rhs::evaluate {
     my ( $data, $parse ) = @_;
@@ -323,17 +329,17 @@ sub Marpa::R2::Internal::MetaAST_Nodes::rhs::evaluate {
 
 sub Marpa::R2::Internal::MetaAST_Nodes::rhs_primary::evaluate {
     my ( $data, $parse ) = @_;
-    my (undef, undef, @values) = @{$data};
+    my ( undef, undef, @values ) = @{$data};
     my @symbol_lists = map { $_->evaluate($parse) } @values;
     return Marpa::R2::Internal::MetaAST::Symbol_List->combine(@symbol_lists);
-}
+} ## end sub Marpa::R2::Internal::MetaAST_Nodes::rhs_primary::evaluate
 
 sub Marpa::R2::Internal::MetaAST_Nodes::rhs_primary_list::evaluate {
     my ( $data, $parse ) = @_;
-    my (undef, undef, @values) = @{$data};
+    my ( undef, undef, @values ) = @{$data};
     my @symbol_lists = map { $_->evaluate($parse) } @values;
     return Marpa::R2::Internal::MetaAST::Symbol_List->combine(@symbol_lists);
-}
+} ## end sub Marpa::R2::Internal::MetaAST_Nodes::rhs_primary_list::evaluate
 
 sub Marpa::R2::Internal::MetaAST_Nodes::action::evaluate {
     my ( $values, $parse ) = @_;
@@ -342,7 +348,7 @@ sub Marpa::R2::Internal::MetaAST_Nodes::action::evaluate {
 }
 
 sub Marpa::R2::Internal::MetaAST_Nodes::blessing::evaluate {
-    my ($values, $parse) = @_;
+    my ( $values, $parse ) = @_;
     my ( undef, undef, $child ) = @{$values};
     return bless { bless => $child->name($parse) }, $PROTO_ALTERNATIVE;
 }
@@ -393,15 +399,15 @@ sub Marpa::R2::Internal::MetaAST_Nodes::rank_specification::evaluate {
 }
 
 sub Marpa::R2::Internal::MetaAST_Nodes::before_or_after::value {
-   return $_[0]->[2];
+    return $_[0]->[2];
 }
 
 sub Marpa::R2::Internal::MetaAST_Nodes::boolean::value {
-   return $_[0]->[2];
+    return $_[0]->[2];
 }
 
 sub Marpa::R2::Internal::MetaAST_Nodes::signed_integer::value {
-   return $_[0]->[2];
+    return $_[0]->[2];
 }
 
 sub Marpa::R2::Internal::MetaAST_Nodes::separator_specification::evaluate {
@@ -418,8 +424,7 @@ sub Marpa::R2::Internal::MetaAST_Nodes::adverb_item::evaluate {
 
 sub Marpa::R2::Internal::MetaAST_Nodes::default_rule::evaluate {
     my ( $values, $parse ) = @_;
-    my ( $start, $length, undef, $op_declare, $raw_adverb_list ) =
-        @{$values};
+    my ( $start, $length, undef, $op_declare, $raw_adverb_list ) = @{$values};
     my $grammar_level = $op_declare->op() eq q{::=} ? 1 : 0;
     my $adverb_list = $raw_adverb_list->evaluate($parse);
 
@@ -429,19 +434,20 @@ sub Marpa::R2::Internal::MetaAST_Nodes::default_rule::evaluate {
 
     ADVERB: for my $key ( keys %{$adverb_list} ) {
         my $value = $adverb_list->{$key};
-        if ( $key eq 'action' and $grammar_level == 1) {
+        if ( $key eq 'action' and $grammar_level == 1 ) {
             $default_adverbs{$key} = $adverb_list->{$key};
             next ADVERB;
         }
-        if ( $key eq 'bless' and $grammar_level == 1) {
+        if ( $key eq 'bless' and $grammar_level == 1 ) {
             $default_adverbs{$key} = $adverb_list->{$key};
             next ADVERB;
         }
         die qq{Adverb "$key" not allowed in G$grammar_level default rule\n},
-            "  Rule was ", $parse->substring( $start, $length ), "\n";
+            '  Rule was ', $parse->substring( $start, $length ), "\n";
     } ## end ADVERB: for my $key ( keys %{$adverb_list} )
+    ## no critic(Subroutines::ProhibitExplicitReturnUndef)
     return undef;
-} ## end sub evaluate
+} ## end sub Marpa::R2::Internal::MetaAST_Nodes::default_rule::evaluate
 
 sub Marpa::R2::Internal::MetaAST_Nodes::lexeme_default_statement::evaluate {
     my ( $data, $parse ) = @_;
@@ -471,12 +477,14 @@ sub Marpa::R2::Internal::MetaAST_Nodes::lexeme_default_statement::evaluate {
         Marpa::R2::exception(
             qq{"$key" adverb not allowed as lexeme default"});
     } ## end ADVERB: for my $key ( keys %{$adverb_list} )
+    ## no critic(Subroutines::ProhibitExplicitReturnUndef)
     return undef;
 } ## end sub Marpa::R2::Internal::MetaAST_Nodes::lexeme_default_statement::evaluate
 
 sub Marpa::R2::Internal::MetaAST_Nodes::priority_rule::evaluate {
     my ( $values, $parse ) = @_;
-    my ( $start, $length, $raw_lhs, $op_declare, $raw_priorities ) = @{$values};
+    my ( $start, $length, $raw_lhs, $op_declare, $raw_priorities ) =
+        @{$values};
 
     my $grammar_level = $op_declare->op() eq q{::=} ? 1 : 0;
     local $Marpa::R2::Internal::GRAMMAR_LEVEL = $grammar_level;
@@ -509,7 +517,8 @@ sub Marpa::R2::Internal::MetaAST_Nodes::priority_rule::evaluate {
                 Marpa::R2::exception(
                     qq{$eval_error\n},
                     qq{  The problem was in this RHS alternative:\n},
-                    q{  }, $parse->substring( $alternative_start, $alternative_end ),
+                    q{  },
+                    $parse->substring( $alternative_start, $alternative_end ),
                     "\n"
                 );
             } ## end if ( not $eval_ok )
@@ -523,33 +532,35 @@ sub Marpa::R2::Internal::MetaAST_Nodes::priority_rule::evaluate {
             my %hash_rule =
                 ( lhs => $lhs, rhs => \@rhs_names, mask => \@mask );
 
-    my $action;
-    my $blessing;
-    my $rank;
-    ADVERB: for my $key ( keys %{$adverb_list} ) {
-        my $value = $adverb_list->{$key};
-        if ( $key eq 'action' ) {
-            $action = $adverb_list->{$key};
-            next ADVERB;
-        }
-        if ( $key eq 'assoc' ) {
-            # OK, but ignored
-            next ADVERB;
-        }
-        if ( $key eq 'bless' ) {
-            $blessing = $adverb_list->{$key};
-            next ADVERB;
-        }
-        if ( $key eq 'rank' ) {
-            $rank = $adverb_list->{$key};
-            next ADVERB;
-        }
-        my ( $line, $column ) = $parse->{meta_recce}->line_column($start);
-        die qq{Adverb "$key" not allowed in an empty rule\n},
-            "  Rule was ", $parse->substring( $start, $length ), "\n";
-    }
+            my $action;
+            my $blessing;
+            my $rank;
+            ADVERB: for my $key ( keys %{$adverb_list} ) {
+                my $value = $adverb_list->{$key};
+                if ( $key eq 'action' ) {
+                    $action = $adverb_list->{$key};
+                    next ADVERB;
+                }
+                if ( $key eq 'assoc' ) {
 
-    $action //= $default_adverbs->{action};
+                    # OK, but ignored
+                    next ADVERB;
+                }
+                if ( $key eq 'bless' ) {
+                    $blessing = $adverb_list->{$key};
+                    next ADVERB;
+                }
+                if ( $key eq 'rank' ) {
+                    $rank = $adverb_list->{$key};
+                    next ADVERB;
+                }
+                my ( $line, $column ) =
+                    $parse->{meta_recce}->line_column($start);
+                die qq{Adverb "$key" not allowed in an empty rule\n},
+                    '  Rule was ', $parse->substring( $start, $length ), "\n";
+            } ## end ADVERB: for my $key ( keys %{$adverb_list} )
+
+            $action //= $default_adverbs->{action};
             if ( defined $action ) {
                 Marpa::R2::exception(
                     'actions not allowed in lexical rules (rules LHS was "',
@@ -558,7 +569,7 @@ sub Marpa::R2::Internal::MetaAST_Nodes::priority_rule::evaluate {
                 $hash_rule{action} = $action;
             } ## end if ( defined $action )
 
-    $rank //= $default_adverbs->{rank};
+            $rank //= $default_adverbs->{rank};
             if ( defined $rank ) {
                 Marpa::R2::exception(
                     'ranks not allowed in lexical rules (rules LHS was "',
@@ -567,7 +578,7 @@ sub Marpa::R2::Internal::MetaAST_Nodes::priority_rule::evaluate {
                 $hash_rule{rank} = $rank;
             } ## end if ( defined $rank )
 
-    $blessing //= $default_adverbs->{bless};
+            $blessing //= $default_adverbs->{bless};
             if ( defined $blessing
                 and $grammar_level <= 0 )
             {
@@ -580,6 +591,7 @@ sub Marpa::R2::Internal::MetaAST_Nodes::priority_rule::evaluate {
 
             push @{$rules}, \%hash_rule;
         } ## end for my $alternative (@alternatives)
+        ## no critic(Subroutines::ProhibitExplicitReturnUndef)
         return undef;
     } ## end if ( $priority_count <= 1 )
 
@@ -590,7 +602,7 @@ sub Marpa::R2::Internal::MetaAST_Nodes::priority_rule::evaluate {
             my ($alternative_start, $alternative_end,
                 $raw_rhs,           $raw_adverb_list
             ) = @{$alternative};
-            my ($adverb_list, $rhs);
+            my ( $adverb_list, $rhs );
             my $eval_ok = eval {
                 $adverb_list = $raw_adverb_list->evaluate($parse);
                 $rhs         = $raw_rhs->evaluate($parse);
@@ -602,7 +614,8 @@ sub Marpa::R2::Internal::MetaAST_Nodes::priority_rule::evaluate {
                 Marpa::R2::exception(
                     qq{$eval_error\n},
                     qq{  The problem was in this RHS alternative:\n},
-                    q{  }, $parse->substring( $alternative_start, $alternative_end ),
+                    q{  },
+                    $parse->substring( $alternative_start, $alternative_end ),
                     "\n"
                 );
             } ## end if ( not $eval_ok )
@@ -625,9 +638,9 @@ sub Marpa::R2::Internal::MetaAST_Nodes::priority_rule::evaluate {
         );
     RULE: for my $working_rule (@working_rules) {
         my ( $priority, $rhs, $adverb_list ) = @{$working_rule};
-        my @new_rhs     = @{ $rhs->{rhs} };
-        my @arity       = grep { $new_rhs[$_] eq $lhs } 0 .. $#new_rhs;
-        my $length      = scalar @new_rhs;
+        my @new_rhs = @{ $rhs->{rhs} };
+        my @arity   = grep { $new_rhs[$_] eq $lhs } 0 .. $#new_rhs;
+        my $rhs_length  = scalar @new_rhs;
 
         my $current_exp = $lhs . '[prec' . $priority . ']';
         my @mask        = @{ $rhs->{mask} };
@@ -640,36 +653,36 @@ sub Marpa::R2::Internal::MetaAST_Nodes::priority_rule::evaluate {
         my %new_xs_rule = ( lhs => $current_exp );
         $new_xs_rule{mask} = \@mask;
 
-    my $action;
-    my $assoc;
-    my $blessing;
-    my $rank;
-    ADVERB: for my $key ( keys %{$adverb_list} ) {
-        my $value = $adverb_list->{$key};
-        if ( $key eq 'action' ) {
-            $action = $adverb_list->{$key};
-            next ADVERB;
-        }
-        if ( $key eq 'assoc' ) {
-            $assoc = $adverb_list->{$key};
-            next ADVERB;
-        }
-        if ( $key eq 'bless' ) {
-            $blessing = $adverb_list->{$key};
-            next ADVERB;
-        }
-        if ( $key eq 'rank' ) {
-            $rank = $adverb_list->{$key};
-            next ADVERB;
-        }
-        my ( $line, $column ) = $parse->{meta_recce}->line_column($start);
-        die qq{Adverb "$key" not allowed in an empty rule\n},
-            "  Rule was ", $parse->substring( $start, $length ), "\n";
-    }
+        my $action;
+        my $assoc;
+        my $blessing;
+        my $rank;
+        ADVERB: for my $key ( keys %{$adverb_list} ) {
+            my $value = $adverb_list->{$key};
+            if ( $key eq 'action' ) {
+                $action = $adverb_list->{$key};
+                next ADVERB;
+            }
+            if ( $key eq 'assoc' ) {
+                $assoc = $adverb_list->{$key};
+                next ADVERB;
+            }
+            if ( $key eq 'bless' ) {
+                $blessing = $adverb_list->{$key};
+                next ADVERB;
+            }
+            if ( $key eq 'rank' ) {
+                $rank = $adverb_list->{$key};
+                next ADVERB;
+            }
+            my ( $line, $column ) = $parse->{meta_recce}->line_column($start);
+            die qq{Adverb "$key" not allowed in an empty rule\n},
+                '  Rule was ', $parse->substring( $start, $length ), "\n";
+        } ## end ADVERB: for my $key ( keys %{$adverb_list} )
 
-    $assoc       //= 'L';
+        $assoc //= 'L';
 
-    $action //= $default_adverbs->{action};
+        $action //= $default_adverbs->{action};
         if ( defined $action ) {
             Marpa::R2::exception(
                 'actions not allowed in lexical rules (rules LHS was "',
@@ -678,7 +691,7 @@ sub Marpa::R2::Internal::MetaAST_Nodes::priority_rule::evaluate {
             $new_xs_rule{action} = $action;
         } ## end if ( defined $action )
 
-    $rank //= $default_adverbs->{rank};
+        $rank //= $default_adverbs->{rank};
         if ( defined $rank ) {
             Marpa::R2::exception(
                 'ranks not allowed in lexical rules (rules LHS was "',
@@ -687,7 +700,7 @@ sub Marpa::R2::Internal::MetaAST_Nodes::priority_rule::evaluate {
             $new_xs_rule{rank} = $rank;
         } ## end if ( defined $rank )
 
-    $blessing //= $default_adverbs->{bless};
+        $blessing //= $default_adverbs->{bless};
         if ( defined $blessing
             and $grammar_level <= 0 )
         {
@@ -709,7 +722,7 @@ sub Marpa::R2::Internal::MetaAST_Nodes::priority_rule::evaluate {
         }
 
         if ( scalar @arity == 1 ) {
-            die 'Unnecessary unit rule in priority rule' if $length == 1;
+            die 'Unnecessary unit rule in priority rule' if $rhs_length == 1;
             $new_rhs[ $arity[0] ] = $current_exp;
         }
         DO_ASSOCIATION: {
@@ -739,12 +752,14 @@ sub Marpa::R2::Internal::MetaAST_Nodes::priority_rule::evaluate {
         $new_xs_rule{rhs} = \@new_rhs;
         push @{$rules}, \%new_xs_rule;
     } ## end RULE: for my $working_rule (@working_rules)
+    ## no critic(Subroutines::ProhibitExplicitReturnUndef)
     return undef;
 } ## end sub Marpa::R2::Internal::MetaAST_Nodes::priority_rule::evaluate
 
 sub Marpa::R2::Internal::MetaAST_Nodes::empty_rule::evaluate {
     my ( $values, $parse ) = @_;
-    my ( $start, $length, $raw_lhs, $op_declare, $raw_adverb_list ) = @{$values};
+    my ( $start, $length, $raw_lhs, $op_declare, $raw_adverb_list ) =
+        @{$values};
 
     my $lhs = $raw_lhs->name($parse);
     my $grammar_level = $op_declare->op() eq q{::=} ? 1 : 0;
@@ -774,7 +789,7 @@ sub Marpa::R2::Internal::MetaAST_Nodes::empty_rule::evaluate {
         }
         my ( $line, $column ) = $parse->{meta_recce}->line_column($start);
         die qq{Adverb "$key" not allowed in an empty rule\n},
-            "  Rule was ", $parse->substring( $start, $length ), "\n";
+            '  Rule was ', $parse->substring( $start, $length ), "\n";
     } ## end ADVERB: for my $key ( keys %{$adverb_list} )
 
     $action //= $default_adverbs->{action};
@@ -826,7 +841,7 @@ sub Marpa::R2::Internal::MetaAST_Nodes::lexeme_rule::evaluate {
         die "Duplicate lexeme rule for <$symbol_name>\n",
             "  Only one lexeme rule is allowed for each symbol\n",
             "  Location was line $line, column $column\n",
-            "  Rule was ", $parse->substring( $start, $length ), "\n";
+            '  Rule was ', $parse->substring( $start, $length ), "\n";
     } ## end if ( defined $declarations )
 
     my $adverb_list = $unevaluated_adverb_list->evaluate();
@@ -849,7 +864,7 @@ sub Marpa::R2::Internal::MetaAST_Nodes::lexeme_rule::evaluate {
             my ( $line, $column ) = $parse->{meta_recce}->line_column($start);
             die qq{Bad value for "pause" adverb: "$raw_value"},
                 "  Location was line $line, column $column\n",
-                "  Rule was ", $parse->substring( $start, $length ), "\n";
+                '  Rule was ', $parse->substring( $start, $length ), "\n";
         } ## end if ( $key eq 'pause' )
         if ( $key eq 'event' ) {
             $declarations{$key} = $raw_value;
@@ -858,7 +873,7 @@ sub Marpa::R2::Internal::MetaAST_Nodes::lexeme_rule::evaluate {
         my ( $line, $column ) = $parse->{meta_recce}->line_column($start);
         die qq{"$key" adverb not allowed in lexeme rule"\n},
             "  Location was line $line, column $column\n",
-            "  Rule was ", $parse->substring( $start, $length ), "\n";
+            '  Rule was ', $parse->substring( $start, $length ), "\n";
     } ## end ADVERB: for my $key ( keys %{$adverb_list} )
     if ( exists $declarations{'event'} and not exists $declarations{'pause'} )
     {
@@ -866,9 +881,10 @@ sub Marpa::R2::Internal::MetaAST_Nodes::lexeme_rule::evaluate {
         die
             qq{"event" adverb not allowed without "pause" adverb in lexeme rule"\n},
             "  Location was line $line, column $column\n",
-            "  Rule was ", $parse->substring( $start, $length ), "\n";
+            '  Rule was ', $parse->substring( $start, $length ), "\n";
     } ## end if ( exists $declarations{'event'} and not exists $declarations...)
     $parse->{lexeme_declarations}->{$symbol_name} = \%declarations;
+    ## no critic(Subroutines::ProhibitExplicitReturnUndef)
     return undef;
 } ## end sub Marpa::R2::Internal::MetaAST_Nodes::lexeme_rule::evaluate
 
@@ -876,15 +892,17 @@ sub Marpa::R2::Internal::MetaAST_Nodes::statement::evaluate {
     my ( $data, $parse ) = @_;
     my ( undef, undef, $statement_body ) = @{$data};
     $statement_body->evaluate($parse);
+    ## no critic(Subroutines::ProhibitExplicitReturnUndef)
     return undef;
-}
+} ## end sub Marpa::R2::Internal::MetaAST_Nodes::statement::evaluate
 
 sub Marpa::R2::Internal::MetaAST_Nodes::statement_body::evaluate {
     my ( $data, $parse ) = @_;
     my ( undef, undef, $statement ) = @{$data};
     $statement->evaluate($parse);
+    ## no critic(Subroutines::ProhibitExplicitReturnUndef)
     return undef;
-}
+} ## end sub Marpa::R2::Internal::MetaAST_Nodes::statement_body::evaluate
 
 sub Marpa::R2::Internal::MetaAST_Nodes::start_rule::evaluate {
     my ( $values, $parse ) = @_;
@@ -896,6 +914,7 @@ sub Marpa::R2::Internal::MetaAST_Nodes::start_rule::evaluate {
         rhs    => $symbol->names($parse),
         action => '::first'
         };
+    ## no critic(Subroutines::ProhibitExplicitReturnUndef)
     return undef;
 } ## end sub Marpa::R2::Internal::MetaAST_Nodes::start_rule::evaluate
 
@@ -905,17 +924,19 @@ sub Marpa::R2::Internal::MetaAST_Nodes::discard_rule::evaluate {
     local $Marpa::R2::Internal::GRAMMAR_LEVEL = 0;
     push @{ $parse->{g0_rules} },
         { lhs => '[:discard]', rhs => $symbol->names($parse) };
+    ## no critic(Subroutines::ProhibitExplicitReturnUndef)
     return undef;
 } ## end sub Marpa::R2::Internal::MetaAST_Nodes::discard_rule::evaluate
 
 sub Marpa::R2::Internal::MetaAST_Nodes::quantified_rule::evaluate {
     my ( $values, $parse ) = @_;
-    my ( $start, $length, $lhs, $op_declare, $rhs, $quantifier, $proto_adverb_list ) =
-        @{$values};
+    my ( $start, $length, $lhs, $op_declare, $rhs, $quantifier,
+        $proto_adverb_list )
+        = @{$values};
     my $grammar_level = $op_declare->op() eq q{::=} ? 1 : 0;
     local $Marpa::R2::Internal::GRAMMAR_LEVEL = $grammar_level;
 
-    my $adverb_list = $proto_adverb_list->evaluate($parse);
+    my $adverb_list     = $proto_adverb_list->evaluate($parse);
     my $default_adverbs = $parse->{default_adverbs}->[$grammar_level];
 
     # Some properties of the sequence rule will not be altered
@@ -956,12 +977,12 @@ sub Marpa::R2::Internal::MetaAST_Nodes::quantified_rule::evaluate {
         }
         my ( $line, $column ) = $parse->{meta_recce}->line_column($start);
         die qq{Adverb "$key" not allowed in quantified rule\n},
-            "  Rule was ", $parse->substring( $start, $length ), "\n";
+            '  Rule was ', $parse->substring( $start, $length ), "\n";
     } ## end ADVERB: for my $key ( keys %{$adverb_list} )
 
     # mask not needed
-    my $lhs_name       = $lhs->name($parse);
-    $sequence_rule{lhs}       = $lhs_name;
+    my $lhs_name = $lhs->name($parse);
+    $sequence_rule{lhs} = $lhs_name;
 
     $sequence_rule{separator} = $separator
         if defined $separator;
@@ -986,12 +1007,11 @@ sub Marpa::R2::Internal::MetaAST_Nodes::quantified_rule::evaluate {
     } ## end if ( defined $rank )
 
     $blessing //= $default_adverbs->{bless};
-    if ( defined $blessing and $grammar_level <= 0 )
-    {
+    if ( defined $blessing and $grammar_level <= 0 ) {
         Marpa::R2::exception(
             'bless option not allowed in lexical rules (rules LHS was "',
             $lhs, '")' );
-    } ## end if ( defined $blessing and $grammar_level <= 0 )
+    }
     $parse->bless_hash_rule( \%sequence_rule, $blessing, $lhs_name );
 
     if ( $grammar_level > 0 ) {
@@ -1004,22 +1024,25 @@ sub Marpa::R2::Internal::MetaAST_Nodes::quantified_rule::evaluate {
 
 } ## end sub Marpa::R2::Internal::MetaAST_Nodes::quantified_rule::evaluate
 
-sub Marpa::R2::Internal::MetaAST_Nodes::completion_event_declaration::evaluate {
+sub Marpa::R2::Internal::MetaAST_Nodes::completion_event_declaration::evaluate
+{
     my ( $values, $parse ) = @_;
-    my ( $start, $length, $raw_event_name, $raw_symbol_name) = @{$values};
-    my $event_name = $raw_event_name->name();
-    my $symbol_name = $raw_symbol_name->name();
+    my ( $start, $length, $raw_event_name, $raw_symbol_name ) = @{$values};
+    my $event_name        = $raw_event_name->name();
+    my $symbol_name       = $raw_symbol_name->name();
     my $completion_events = $parse->{completion_events} //= {};
-    if (defined $completion_events->{$symbol_name}) {
-        my ($line, $column) = $parse->{meta_recce}->line_column($start);
+    if ( defined $completion_events->{$symbol_name} ) {
+        my ( $line, $column ) = $parse->{meta_recce}->line_column($start);
         die qq{Completion event for symbol "$symbol_name" declared twice\n},
             qq{  That is not allowed\n},
-            "  Second declaration was ", $parse->substring( $start, $length ), "\n",
+            '  Second declaration was ', $parse->substring( $start, $length ),
+            "\n",
             "  Problem occurred at line $line, column $column\n";
-    }
+    } ## end if ( defined $completion_events->{$symbol_name} )
     $completion_events->{$symbol_name} = $event_name;
+    ## no critic(Subroutines::ProhibitExplicitReturnUndef)
     return undef;
-} ## end sub evaluate
+} ## end sub Marpa::R2::Internal::MetaAST_Nodes::completion_event_declaration::evaluate
 
 sub Marpa::R2::Internal::MetaAST_Nodes::nulled_event_declaration::evaluate {
     my ( $values, $parse ) = @_;
@@ -1031,11 +1054,12 @@ sub Marpa::R2::Internal::MetaAST_Nodes::nulled_event_declaration::evaluate {
         my ( $line, $column ) = $parse->{meta_recce}->line_column($start);
         die qq{nulled event for symbol "$symbol_name" declared twice\n},
             qq{  That is not allowed\n},
-            "  Second declaration was ", $parse->substring( $start, $length ),
+            '  Second declaration was ', $parse->substring( $start, $length ),
             "\n",
             "  Problem occurred at line $line, column $column\n";
     } ## end if ( defined $nulled_events->{$symbol_name} )
     $nulled_events->{$symbol_name} = $event_name;
+    ## no critic(Subroutines::ProhibitExplicitReturnUndef)
     return undef;
 } ## end sub Marpa::R2::Internal::MetaAST_Nodes::nulled_event_declaration::evaluate
 
@@ -1050,11 +1074,12 @@ sub Marpa::R2::Internal::MetaAST_Nodes::prediction_event_declaration::evaluate
         my ( $line, $column ) = $parse->{meta_recce}->line_column($start);
         die qq{prediction event for symbol "$symbol_name" declared twice\n},
             qq{  That is not allowed\n},
-            "  Second declaration was ", $parse->substring( $start, $length ),
+            '  Second declaration was ', $parse->substring( $start, $length ),
             "\n",
             "  Problem occurred at line $line, column $column\n";
     } ## end if ( defined $prediction_events->{$symbol_name} )
     $prediction_events->{$symbol_name} = $event_name;
+    ## no critic(Subroutines::ProhibitExplicitReturnUndef)
     return undef;
 } ## end sub Marpa::R2::Internal::MetaAST_Nodes::prediction_event_declaration::evaluate
 
@@ -1096,8 +1121,9 @@ sub Marpa::R2::Internal::MetaAST_Nodes::single_symbol::name {
 sub Marpa::R2::Internal::MetaAST_Nodes::single_symbol::evaluate {
     my ( $values, $parse ) = @_;
     my ( undef, undef, $symbol ) = @{$values};
-    return Marpa::R2::Internal::MetaAST::Symbol_List->new($symbol->name($parse));
-}
+    return Marpa::R2::Internal::MetaAST::Symbol_List->new(
+        $symbol->name($parse) );
+} ## end sub Marpa::R2::Internal::MetaAST_Nodes::single_symbol::evaluate
 
 sub Marpa::R2::Internal::MetaAST_Nodes::Symbol::evaluate {
     my ( $values, $parse ) = @_;
@@ -1114,14 +1140,20 @@ sub Marpa::R2::Internal::MetaAST_Nodes::symbol::names {
     my ( $self, $parse ) = @_;
     return $self->[2]->names($parse);
 }
+
 sub Marpa::R2::Internal::MetaAST_Nodes::symbol_name::evaluate {
-my ($self) = @_; return $self->[2]; }
+    my ($self) = @_;
+    return $self->[2];
+}
+
 sub Marpa::R2::Internal::MetaAST_Nodes::symbol_name::name {
-my ($self, $parse) = @_;
-return $self->evaluate($parse)->name($parse); }
+    my ( $self, $parse ) = @_;
+    return $self->evaluate($parse)->name($parse);
+}
+
 sub Marpa::R2::Internal::MetaAST_Nodes::symbol_name::names {
-    my ($self, $parse) = @_;
-   return [$self->name($parse)];
+    my ( $self, $parse ) = @_;
+    return [ $self->name($parse) ];
 }
 
 sub Marpa::R2::Internal::MetaAST_Nodes::adverb_list::evaluate {
@@ -1130,17 +1162,17 @@ sub Marpa::R2::Internal::MetaAST_Nodes::adverb_list::evaluate {
     my (@adverb_items) = map { $_->evaluate($parse) } @raw_items;
     return Marpa::R2::Internal::MetaAST::Proto_Alternative->combine(
         @adverb_items);
-} ## end sub evaluate
+} ## end sub Marpa::R2::Internal::MetaAST_Nodes::adverb_list::evaluate
 
 sub Marpa::R2::Internal::MetaAST_Nodes::character_class::name {
     my ( $self, $parse ) = @_;
     return $self->evaluate($parse)->name($parse);
 }
-sub Marpa::R2::Internal::MetaAST_Nodes::character_class::names {
-    my ($self, $parse) = @_;
-   return [$self->name($parse)];
-}
 
+sub Marpa::R2::Internal::MetaAST_Nodes::character_class::names {
+    my ( $self, $parse ) = @_;
+    return [ $self->name($parse) ];
+}
 
 sub Marpa::R2::Internal::MetaAST_Nodes::character_class::evaluate {
     my ( $values, $parse ) = @_;
@@ -1157,7 +1189,8 @@ sub Marpa::R2::Internal::MetaAST_Nodes::character_class::evaluate {
         mask => [1],
     );
     push @{ $parse->{g0_rules} }, \%lexical_rule;
-    my $g1_symbol = Marpa::R2::Internal::MetaAST::Symbol_List->new($lexical_lhs);
+    my $g1_symbol =
+        Marpa::R2::Internal::MetaAST::Symbol_List->new($lexical_lhs);
     return $g1_symbol;
 } ## end sub Marpa::R2::Internal::MetaAST_Nodes::character_class::evaluate
 
@@ -1184,10 +1217,11 @@ sub Marpa::R2::Internal::MetaAST_Nodes::single_quoted_string::evaluate {
     my %lexical_rule      = (
         lhs  => $lexical_lhs,
         rhs  => $lexical_rhs,
-        mask => [ map { ; 1 } @{$lexical_rhs} ]
+        mask => [ map { ; 1 } @{$lexical_rhs} ],
     );
     push @{ $parse->{g0_rules} }, \%lexical_rule;
-    my $g1_symbol = Marpa::R2::Internal::MetaAST::Symbol_List->new($lexical_lhs);
+    my $g1_symbol =
+        Marpa::R2::Internal::MetaAST::Symbol_List->new($lexical_lhs);
     return $g1_symbol;
 } ## end sub Marpa::R2::Internal::MetaAST_Nodes::single_quoted_string::evaluate
 
@@ -1197,7 +1231,7 @@ use English qw( -no_match_vars );
 
 sub new {
     my ( $class, $name ) = @_;
-    return bless { names => [ '' . $name ], mask => [1] }, $class;
+    return bless { names => [ q{} . $name ], mask => [1] }, $class;
 }
 
 sub combine {
@@ -1206,7 +1240,7 @@ sub combine {
     $self->{names} = [ map { @{ $_->names() } } @lists ];
     $self->{mask}  = [ map { @{ $_->mask() } } @lists ];
     return bless $self, $class;
-} ## end sub new
+} ## end sub combine
 
 # Return the character class symbol name,
 # after ensuring everything is set up properly
@@ -1234,16 +1268,17 @@ sub new_from_char_class {
 sub name {
     my ($self) = @_;
     my $names = $self->{names};
-    Marpa::R2::exception( "list->name() on symbol list of length ",
+    Marpa::R2::exception( 'list->name() on symbol list of length ',
         scalar @{$names} )
         if scalar @{$names} != 1;
     return $self->{names}->[0];
 } ## end sub name
 sub names { return shift->{names} }
-sub mask { return shift->{mask} }
+sub mask  { return shift->{mask} }
+
 sub mask_set {
     my ( $self, $mask ) = @_;
-    $self->{mask} = [ map { $mask } @{ $self->{mask} } ];
+    return $self->{mask} = [ map {$mask} @{ $self->{mask} } ];
 }
 
 1;
