@@ -20,7 +20,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION $STRING_VERSION);
-$VERSION        = '2.064000';
+$VERSION        = '2.066000';
 $STRING_VERSION = $VERSION;
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 $VERSION = eval $VERSION;
@@ -780,7 +780,7 @@ sub code_problems {
 } ## end sub code_problems
 
 sub Marpa::R2::Internal::Recognizer::evaluate {
-    my ($recce) = @_;
+    my ($recce, $slr) = @_;
     my $recce_c = $recce->[Marpa::R2::Internal::Recognizer::C];
     my $bocage  = $recce->[Marpa::R2::Internal::Recognizer::B_C];
     my $order   = $recce->[Marpa::R2::Internal::Recognizer::O_C];
@@ -861,7 +861,6 @@ sub Marpa::R2::Internal::Recognizer::evaluate {
 
     my $value = Marpa::R2::Thin::V->new($tree);
     $value->valued_force();
-    my $slr = $recce->[Marpa::R2::Internal::Recognizer::SLR];
     if ($slr) {
         $value->slr_set($slr->thin());
     }
@@ -1348,17 +1347,20 @@ sub Marpa::R2::Internal::Recognizer::evaluate {
 # Returns false if no parse
 sub Marpa::R2::Recognizer::value
 {    ## no critic (Subroutines::RequireArgUnpacking)
-    my ($recce) = @_;
+    my ($recce, $slr) = @_;
 
-    Marpa::R2::exception('Too many arguments to Marpa::R2::Recognizer::value')
-        if scalar @_ != 1;
+    if ( scalar @_ != 1 ) {
+        Marpa::R2::exception(
+            'Too many arguments to Marpa::R2::Recognizer::value')
+            if ref $slr ne 'Marpa::R2::Scanless::R';
+    }
 
     my $grammar   = $recce->[Marpa::R2::Internal::Recognizer::GRAMMAR];
     my $grammar_c = $grammar->[Marpa::R2::Internal::Grammar::C];
     my $recce_c   = $recce->[Marpa::R2::Internal::Recognizer::C];
     my $order     = $recce->[Marpa::R2::Internal::Recognizer::O_C];
 
-    my $parse_set_arg = $recce->[Marpa::R2::Internal::Recognizer::END];
+    my $parse_set_arg = $recce->[Marpa::R2::Internal::Recognizer::END_OF_PARSE];
 
     local $Marpa::R2::Internal::TRACE_FH =
         $recce->[Marpa::R2::Internal::Recognizer::TRACE_FILE_HANDLE];
@@ -1394,7 +1396,7 @@ sub Marpa::R2::Recognizer::value
 
     } ## end if ($bocage)
     else {
-    # No bocage, therefor not initialized
+    # No bocage, therefore not initialized
 
         $grammar_c->throw_set(0);
         $bocage = $recce->[Marpa::R2::Internal::Recognizer::B_C] =
@@ -1443,7 +1445,7 @@ sub Marpa::R2::Recognizer::value
     }
 
     return if not defined $tree->next();
-    return \Marpa::R2::Internal::Recognizer::evaluate($recce);
+    return \Marpa::R2::Internal::Recognizer::evaluate($recce, $slr);
 
 } ## end sub Marpa::R2::Recognizer::value
 
@@ -1690,6 +1692,45 @@ sub Marpa::R2::Recognizer::show_or_nodes {
     return ( join "\n", @sorted_data ) . "\n";
 } ## end sub Marpa::R2::Recognizer::show_or_nodes
 
+# Not sorted and therefore not suitable for test suite
+sub Marpa::R2::Recognizer::verbose_or_nodes {
+    my ($recce) = @_;
+    my $text = q{};
+    OR_NODE:
+    for (
+        my $or_node_id = 0;
+        defined( my $or_node_desc = $recce->verbose_or_node($or_node_id) );
+        $or_node_id++
+        )
+    {
+        $text .= $or_node_desc;
+    } ## end OR_NODE: for ( my $or_node_id = 0; defined( my $or_node_desc =...))
+    return $text;
+} ## end sub Marpa::R2::Recognizer::verbose_or_nodes
+
+sub Marpa::R2::Recognizer::verbose_or_node {
+    my ( $recce, $or_node_id ) = @_;
+    my $recce_c = $recce->[Marpa::R2::Internal::Recognizer::C];
+    my $bocage  = $recce->[Marpa::R2::Internal::Recognizer::B_C];
+    my $origin  = $bocage->_marpa_b_or_node_origin($or_node_id);
+    return if not defined $origin;
+    my $grammar         = $recce->[Marpa::R2::Internal::Recognizer::GRAMMAR];
+    my $tracer          = $grammar->[Marpa::R2::Internal::Grammar::TRACER];
+    my $set             = $bocage->_marpa_b_or_node_set($or_node_id);
+    my $irl_id          = $bocage->_marpa_b_or_node_irl($or_node_id);
+    my $position        = $bocage->_marpa_b_or_node_position($or_node_id);
+    my $origin_earleme  = $recce_c->earleme($origin);
+    my $current_earleme = $recce_c->earleme($set);
+    my $text
+        .= "OR-node #$or_node_id: R$irl_id" . q{:}
+        . $position . q{@}
+        . $origin_earleme . q{-}
+        . $current_earleme . "\n";
+    $text .= ( q{ } x 4 )
+        . $tracer->show_dotted_irl( $irl_id, $position ) . "\n";
+    return $text;
+} ## end sub Marpa::R2::Recognizer::verbose_or_node
+
 sub Marpa::R2::Recognizer::show_nook {
     my ( $recce, $nook_id, $verbose ) = @_;
     my $recce_c = $recce->[Marpa::R2::Internal::Recognizer::C];
